<template>
  <el-row>
    <el-col :span="5" v-if="userflag">
      <div class="box">
        <el-scrollbar style="height: auto;border-bottom-right-radius:8px ">
          <basic-container>
            <div class="abox">
              <avue-tree ref="tree" :data="treeData" :option="treeOption" @node-click="nodeClick"/>
            </div>
          </basic-container>
        </el-scrollbar>
      </div>
    </el-col>
    <el-col :span="usernumber">
      <basic-container>
        <div class="bbox">
        <avue-crud ref="crud"
          v-model="form"
          :before-open="beforeOpen"
          :data="data"
          :option="option"
          :page.sync="page"
          :permission="permissionList"
          :search.sync="search"
          :table-loading="loading"
          @row-del="rowDel"
          @row-update="rowUpdate"
          @row-save="rowSave"
          @search-change="searchChange"
          @search-reset="searchReset"
          @row-click="clickRowChange"
          @selection-change="selectionChange"
          @current-change="currentChange"
          @size-change="sizeChange"
          @refresh-change="refreshChange"
          @on-load="onLoad">
          <template slot="menuLeft">
            <el-button v-if="permissionList.delBtn"
                       icon="el-icon-delete"
                       plain
                       size="small"
                       type="danger"
                       @click="handleDelete">删 除
            </el-button>
            <el-button v-if="permissionList.roleBtn"
                       icon="el-icon-user"
                       plain
                       size="small"
                       type="info"
                       @click="handleGrant">角色配置
            </el-button>
            <el-button v-if="permissionList.resetBtn"
                       icon="el-icon-refresh"
                       plain
                       size="small"
                       type="info"
                       @click="handleReset">密码重置
            </el-button>
            <el-button v-if="permissionList.pwdStrategyBtn"
                        size="small"
                       type="success"
                       icon="el-icon-setting"
                       @click="handlepass">
              配置密码策略
            </el-button>
            <el-button v-if="permissionList.unsealBtn"
              icon="el-icon-coordinate"
              plain
              size="small"
              type="info"
              @click="handleLock">账号解封
            </el-button>
            <el-button v-if="permissionList.importBtn"
              icon="el-icon-upload2"
              plain
              size="small"
              type="success"
              @click="handleImport">导入
            </el-button>
            <el-button v-if="permissionList.exportBtn"
              icon="el-icon-download"
              plain
              size="small"
              type="warning"
              @click="handleExport">导出
            </el-button>
            <el-button v-if="permissionList.deactEnBtn"
                size="small"
                type="warning"
                icon="el-icon-setting"
                @click="updateUserStatus">
              账号停/启用
            </el-button>
          </template>
          <template slot="tenantName"
                    slot-scope="{row}">
            <el-tag>{{ row.tenantName }}</el-tag>
          </template>
          <template slot="roleName"
                    slot-scope="{row}">
            <el-tag>{{ row.roleName }}</el-tag>
          </template>
          <template slot="deptName"
                    slot-scope="{row}">
            <el-tag>{{ row.deptName }}</el-tag>
          </template>
          <template slot="userTypeName"
                    slot-scope="{row}">
            <el-tag>{{ row.userTypeName }}</el-tag>
          </template>
        </avue-crud>
        </div>
        <el-dialog :visible.sync="roleBox"
            append-to-body
            title="用户角色配置"
            width="345px">
          <el-tree ref="treeRole"
              :data="roleGrantList"
              :default-checked-keys="roleTreeObj"
              :props="props"
              check-strictly
              default-expand-all
              node-key="id"
              show-checkbox>
          </el-tree>
          <span slot="footer" class="dialog-footer">
            <el-button @click="roleBox = false">取 消</el-button>
            <el-button type="primary"
                       @click="submitRole">确 定</el-button>
          </span>
        </el-dialog>
        <el-dialog :visible.sync="excelBox"
                   append-to-body
                   title="用户数据导入"
                   width="555px">
          <avue-form v-model="excelForm" :option="excelOption" :upload-after="uploadAfter">
            <template slot="excelTemplate">
              <el-button type="primary" @click="handleTemplate">
                点击下载<i class="el-icon-download el-icon--right"></i>
              </el-button>
            </template>
          </avue-form>
        </el-dialog>
        <!--        设置密码策略弹出框-->
        <el-dialog
          :visible.sync="passVisible"
          class="passdialog"
          append-to-body
          title="设置密码策略"
          width="30%">
          <el-select v-model="sevalue" placeholder="请选择"  class="selects" @change="selChange" >
            <el-option
              v-for="item in seoptions"
              :key="item.id"
              :label="item.strategyName"
              :value="item.id"
              class="seloption"
              >
            </el-option>
          </el-select>
            <span slot="footer" class="dialog-footer">
              <el-button @click="passVisible = false">取 消</el-button>
              <el-button type="primary" @click="passhandle">确 定</el-button>
            </span>
        </el-dialog>
      </basic-container>
    </el-col>
  </el-row>
</template>

<script>
import {
  getList,
  insert,
  getUser,
  getUserPlatform,
  remove,
  update,
  updatePlatform,
  add,
  grant,
  resetPassword,
  unlock,
  updateUserStatus
} from "@/api/system/user";
import {exportBlob} from "@/api/common";
import {getDeptTree, getDeptLazyTree} from "@/api/system/dept";
import {getRoleTree} from "@/api/system/role";
//import {getPostList} from "@/api/system/post";
import {mapGetters} from "vuex";
import website from '@/config/website';
import {getToken} from '@/util/auth';
import {downloadXls} from "@/util/util";
import {dateNow} from "@/util/date";
import NProgress from 'nprogress';
import 'nprogress/nprogress.css';
import func from "@/util/func";
import {getPage} from "@/api/system/passwords";

export default {
  data() {
    return {
      tenantId:'',
      form: {},
      seoptions: [],
      sevalue:"",
      passVisible: false,
      id: '',
      search: {},
      roleBox: false,
      excelBox: false,
      platformBox: false,
      initFlag: true,
      selectionList: [],
      query: {},
      loading: true,
      platformLoading: false,
      page: {
        pageSize: 10,
        currentPage: 1,
        total: 0
      },
      platformPage: {
        pageSize: 10,
        currentPage: 1,
        total: 0
      },
      init: {
        roleTree: [],
        deptTree: [],
      },
      props: {
        label: "title",
        value: "key"
      },
      roleGrantList: [],
      roleTreeObj: [],
      treeDeptId: '',
      treeData: [],
      treeOption: {
        height:"auto",
        nodeKey: 'id',
        border: true,
        lazy: true,
        treeLoad: function (node, resolve) {
          const parentId = (node.level === 0) ? 0 : node.data.id;
          getDeptLazyTree(parentId).then(res => {
            resolve(res.data.data.map(item => {
              return {
                ...item,
                leaf: !item.hasChildren
              }
            }))
          });
        },
        addBtn: false,
        menu: false,
        size: 'small',
        props: {
          labelText: '标题',
          label: 'title',
          value: 'value',
          children: 'children'
        }
      },
      data: [],
      platformQuery: {},
      platformSelectionList: [],
      platformData: [],
      platformForm: {},
      platformOption: {
        tip: false,
        searchShow: true,
        searchMenuSpan: 6,
        border: true,
        index: true,
        selection: true,
        viewBtn: true,
        dialogClickModal: false,
        menuWidth: 120,
        editBtnText: '配置',
        column: [
          {
            label: "登录账号",
            prop: "account",
            search: true,
            display: false
          },
          {
            label: "所属租户",
            prop: "tenantName",
            slot: true,
            display: false
          },
          {
            label: "用户姓名",
            prop: "realName",
            search: true,
            display: false
          },
          {
            label: "用户平台",
            prop: "userTypeName",
            slot: true,
            display: false
          },

          {
            label: "用户平台",
            type: "select",
            dicUrl: "/api/ubcs-system/dict/dictionary?code=user_type",
            props: {
              label: "dictValue",
              value: "dictKey"
            },
            dataType: "number",
            search: true,
            hide: true,
            display: false,
            prop: "userType",
            rules: [{
              required: true,
              message: "请选择用户平台",
              trigger: "blur"
            }]
          },
          {
            label: "用户拓展",
            prop: "userExt",
            type: "textarea",
            minRows: 8,
            span: 24,
            overHidden: true,
            row: true,
            hide: true,
          },
        ],
      },
      excelForm: {},
      excelOption: {
        submitBtn: false,
        emptyBtn: false,
        column: [
          {
            label: '模板上传',
            prop: 'excelFile',
            type: 'upload',
            drag: true,
            loadText: '模板上传中，请稍等',
            span: 24,
            propsHttp: {
              res: 'data'
            },
            tip: '请上传 .xls,.xlsx 标准格式文件',
            action: "/api/ubcs-user/import-user"
          },
          {
            label: "数据覆盖",
            prop: "isCovered",
            type: "switch",
            align: "center",
            width: 80,
            dicData: [
              {
                label: "否",
                value: 0
              },
              {
                label: "是",
                value: 1
              }
            ],
            value: 0,
            slot: true,
            rules: [
              {
                required: true,
                message: "请选择是否覆盖",
                trigger: "blur"
              }
            ]
          },
          {
            label: '模板下载',
            prop: 'excelTemplate',
            formslot: true,
            span: 24,
          }
        ]
      },
      selid:[],
      UserPwdstrategyVO:{
        userIds:[],
        pwdstrategyId:''
      },
      userflag:true,
      usernumber:0,
      userStatus:false,
      isUpdateShowInput:false,
    };
  },
  watch: {
    'form.tenantId'() {
      if (this.form.tenantId !== '' && this.initFlag) {
        this.initData(this.form.tenantId);
        // console.log('this.form.tenantId',this.form.tenantId)
      }
    },
    'excelForm.isCovered'() {
      if (this.excelForm.isCovered !== '') {
        const column = this.findObject(this.excelOption.column, "excelFile");
        column.action = `/api/ubcs-user/import-user?isCovered=${this.excelForm.isCovered}`;
      }
    }
  },
  computed: {
    ...mapGetters(["userInfo", "permission"]),
    /** 按钮显示隐藏控制 */
    permissionList() {
      return {
        addBtn: this.vaildData(this.permission.user.user_add, false),
        viewBtn: this.vaildData(this.permission.user.user_view, false),
        delBtn: this.vaildData(this.permission.user.user_delete, false),
        editBtn: this.vaildData(this.permission.user.user_edit, false),
        deactEnBtn: this.vaildData(this.permission.user.user_deact_en,false),
        exportBtn: this.vaildData(this.permission.user.user_export,false),
        pwdStrategyBtn: this.vaildData(this.permission.user.user_pwd_strategy,false),
        importBtn: this.vaildData(this.permission.user.user_import,false),
        resetBtn: this.vaildData(this.permission.user.user_reset,false),
        roleBtn: this.vaildData(this.permission.user.user_role,false),
        unsealBtn: this.vaildData(this.permission.user.user_unseal,false),
      };
    },
    option() {
      return{
          height:'auto',
          calcHeight: 80,
          tip: false,
          searchShow: true,
          searchMenuSpan: 6,
          columnBtn:false,
          border: true,
          index: true,
          selection: true,
          /* 下面这三个属性默认设置为true，
            实际根据permissionList中对照的属性进行控制的 */
          viewBtn: true,
          editBtn: true,
          delBtn: true,
          addBtn: true,
          dialogType: 'drawer',
          dialogClickModal: false,
          highlightCurrentRow: true, //行选中时高亮
          column: [
            {
              label: "登录账号",
              prop: "account",
              search: true,
              display: false
            },
            {
              label: "所属租户",
              prop: "tenantName",
              slot: true,
              display: false
            },
            {
              label: "用户姓名",
              prop: "realName",
              search: true,
              display: false
            },
            {
              label: "所属角色",
              prop: "roleName",
              slot: true,
              display: false
            },
            {
              label: "密码策略",
              prop: "pwdStrategy",
              slot: true,
              display: false
            },
            {
              label: "所属部门",
              prop: "deptName",
              slot: true,
              display: false
            },
            {
              label: "用户平台",
              prop: "userTypeName",
              slot: true,
              display: false
            },
            {
              label: "用户平台",
              type: "select",
              dicUrl: "/api/ubcs-system/dict/dictionary?code=user_type",
              props: {
                label: "dictValue",
                value: "dictKey"
              },
              dataType: "number",
              search: true,
              hide: true,
              display: false,
              prop: "userType",
              rules: [{
                required: true,
                message: "请选择用户平台",
                trigger: "blur"
              }],
            },
            {
              label: "状态",
              display: false,
              sortable:true,
              html:true,
              prop: "userStatus",
              formatter : function (row, column) {
                return row.userStatus == 0 ? '<i class="el-icon-check" style="color: #32cd32;font-size: 20px;font-weight: 800"></i>' : '<i class="el-icon-close" style="color: #ff0000;font-size: 20px;font-weight: 800"></i>'
              }
            },
          ],
          group: [
            {
              label: '基础信息',
              prop: 'baseInfo',
              icon: 'el-icon-user-solid',
              column: [
                {
                  label: "所属租户",
                  prop: "tenantId",
                  type: "tree",
                  dicUrl: "/api/ubcs-system/tenant/select",
                  props: {
                    label: "tenantName",
                    value: "tenantId"
                  },
                  hide: !website.tenantMode,
                  addDisplay: website.tenantMode,
                  editDisplay: website.tenantMode,
                  viewDisplay: website.tenantMode,
                  rules: [{
                    required: true,
                    message: "请输入所属租户",
                    trigger: "click"
                  }],
                  span: 24,
                  value:""
                },
                {
                  label: "登录账号",
                  prop: "account",
                  rules: [{
                    required: true,
                    message: "请输入登录账号",
                    trigger: "blur"
                  }],
                  disabled: this.isUpdateShowInput,
                },
                {
                  label: "用户平台",
                  type: "select",
                  dicUrl: "/api/ubcs-system/dict/dictionary?code=user_type",
                  props: {
                    label: "dictValue",
                    value: "dictKey"
                  },
                  value:'1',
                  dataType: "number",
                  slot: true,
                  prop: "userType",
                  rules: [{
                    required: true,
                    message: "请选择用户平台",
                    trigger: "blur"
                  }]
                },
                {
                  label: '密码',
                  prop: 'password',
                  type: "password",
                  hide: true,
                  editDisplay: false,
                  viewDisplay: false,
                  rules: [{
                    required: true,
                    validator:(rule, value,callback) => {
                      if (value === '') {
                        callback(new Error('请再次输入密码'));
                      } else if (value !== this.form.password) {
                        callback(new Error('两次输入密码不一致!'));
                      } else {
                        callback();
                      }
                    },
                    trigger: 'blur'
                  }]
                },
                {
                  label: '确认密码',
                  prop: 'password2',
                  hide: true,
                  type: "password",
                  editDisplay: false,
                  viewDisplay: false,
                  rules: [{
                    required: true,
                    validator:(rule, value,callback) => {
                      if (value === '') {
                        callback(new Error('请再次输入密码'));
                      } else if (value !== this.form.password) {
                        callback(new Error('两次输入密码不一致!'));
                      } else {
                        callback();
                      }
                    },
                    trigger: 'blur'
                  }]
                },
              ]
            },
            {
              label: '详细信息',
              prop: 'detailInfo',
              icon: 'el-icon-s-order',
              column: [
                {
                  label: "用户昵称",
                  prop: "name",
                  hide: true,
                  rules: [{
                    required: true,
                    message: "请输入用户昵称",
                    trigger: "blur"
                  }]
                },
                {
                  label: "用户姓名",
                  prop: "realName",
                  rules: [{
                    required: true,
                    message: "请输入用户姓名",
                    trigger: "blur"
                  }, {
                    min: 2,
                    max: 5,
                    message: '姓名长度在2到5个字符'
                  }]
                },
                {
                  label: "手机号码",
                  prop: "phone",
                  overHidden: true
                },
                {
                  label: "电子邮箱",
                  prop: "email",
                  hide: true,
                  overHidden: true
                },
                {
                  label: "用户性别",
                  prop: "sex",
                  type: "select",
                  dicData: [
                    {
                      label: "男",
                      value: 1
                    },
                    {
                      label: "女",
                      value: 2
                    },
                    {
                      label: "未知",
                      value: 3
                    }
                  ],
                  hide: true
                },
                {
                  label: "用户生日",
                  type: "date",
                  prop: "birthday",
                  format: "yyyy-MM-dd hh:mm:ss",
                  valueFormat: "yyyy-MM-dd hh:mm:ss",
                  hide: true
                },
                {
                  label: "账号状态",
                  prop: "statusName",
                  hide: true,
                  display: false
                }
              ]
            },
            {
              label: '职责信息',
              prop: 'dutyInfo',
              icon: 'el-icon-s-custom',
              column: [
                {
                  label: "用户编号",
                  prop: "code",
                },
                {
                  label: "所属角色",
                  prop: "roleId",
                  multiple: true,
                  type: "tree",
                  dicData: [],
                  disabled: this.isUpdateShowInput,
                  props: {
                    label: "title"
                  },
                  checkStrictly: true,
                  slot: true,
                  rules: [{
                    required: true,
                    message: "请选择所属角色",
                    trigger: "click"
                  }]
                },
                {
                  label: "所属部门",
                  prop: "deptId",
                  type: "tree",
                  multiple: true,
                  dicData: [],
                  props: {
                    label: "title"
                  },
                  checkStrictly: true,
                  slot: true,
                  rules: [{
                    required: true,
                    message: "请选择所属部门",
                    trigger: "click"
                  }]
                },
              ]
            },
          ]

      }
    },
    ids() {
      let ids = [];
      this.selectionList.forEach(ele => {
        ids.push(ele.id);
      });
      return ids.join(",");
    },
  },
  mounted() {
    // 非租户模式默认加载管理组数据
    if (!website.tenantMode) {
      this.initData(website.tenantId);
    }
  },
  created() {
    this.selecload()
    const arr=JSON.parse(localStorage.getItem("updataid"))
    if(arr.user_id != '0' && arr.tenant_id !== '000000'){
      this.userflag=false
      this.usernumber=24
    }else {
      this.userflag=true
      this.usernumber=19
    }
  },
  methods: {

    // beOpen(done,type){
    //   console.log(done,type)
    // },
    // 用户停用启用状态
    /** 修改用户状态 */
    updateUserStatus(){
      let list = this.selectionList;
      if(list.length < 1){
        this.$message({
          type: "warning",
          message: "请至少选择一条用户数据！"
        });
        return;
      }
      if(func.isAttrInconsistent(list,"userStatus")){
        this.$message({
          type: "warning",
          message: "批量操作用户状态时，请选择用户状态一致的数据！"
        });
        return;
      }
      let userIds = func.joinedString(list,"id");
      let status = list[0].userStatus == 1 ? true:false;
      let msg = status ? "确定将选择账号启用":"确定将选择账号停用"+"？";
      // console.log(msg);
      this.$confirm(msg, {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return updateUserStatus(userIds,status);
        })
        .then(() => {
          this.$message({
            type: "success",
            message: "操作成功!",
            duration: 1000,// 设置消息显示3秒后自动关闭
            onClose: () => {
              // 在消息关闭时重新加载数据
              this.onLoad(this.page);
            }
          });
        });
    },
    //esc取消键操作
    /*handleClose(done) {
      this.$confirm('确认关闭？')
        .then(() => {
          done();
        })
        .catch(() => {
          done();
        });

    },*/
    //点击配置密码策略
    handlepass(){
      if (this.selectionList.length === 0) {
        this.$message.warning("请选择至少一条数据");
        return;
      }else {
        this.passVisible=true;
      }
    },
    // 设置密码策略，传递下拉框的id和多选框的id
    passhandle(){
      // 重新循环已选中id，定义一个selid数组来赋值
      this.selectionList.forEach(ele => {
        this.selid.push(ele.id);
      })
       //要传递的id，一个是数组另一个是字符串
       this.UserPwdstrategyVO.userIds=this.selid;
       this.UserPwdstrategyVO.pwdstrategyId=this.id

      //请求
      insert(this.UserPwdstrategyVO).then(()=>{
        this.passVisible=false
        this.$message({
          type: "success",
          message: "配置成功!"
        });
        this.onLoad(this.page)
        this.selid=[]
      }).catch(res=>{
        this.selid=[]
        this.$message({
          type: "warning",
          message: res
        });
      })

    },
    //通过下拉框change事件，拿到对应的id赋值给定义的id，传递后端
    selChange(row){
      this.id=row
    },
    selecload() {
      getPage(1, -1).then(res => {
        // console.log(res)
        this.seoptions=res.data.data.records
      });
    },
    nodeClick(data) {
      // console.log(data)
      // console.log(this.form.tenantId)
      this.treeDeptId = data.id;
      this.page.currentPage = 1;
      this.onLoad(this.page);
    },
    initData(tenantId) {
      getRoleTree(tenantId).then(res => {
        const column = this.findObject(this.option.group, "roleId");
        column.dicData = res.data.data;
        this.id = tenantId

      });
      getDeptTree(tenantId).then(res => {
        const column = this.findObject(this.option.group, "deptId");
        column.dicData = res.data.data;
      });
      // getPostList(tenantId).then(res => {
      //   const column = this.findObject(this.option.group, "postId");
      //   column.dicData = res.data.data;
      // });
    },
    submitRole() {
      const roleList = this.$refs.treeRole.getCheckedKeys().join(",");
      grant(this.ids, roleList).then(() => {
        this.roleBox = false;
        this.$message({
          type: "success",
          message: "操作成功!"
        });
        this.onLoad(this.page);
      });
    },
    rowSave(row, done, loading) {
        row.deptId = row.deptId.join(",");
        row.roleId = row.roleId.join(",");
        //row.postId = row.postId.join(",");
        // console.log('3',row)
        add(row).then(() => {
          this.initFlag = false;
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
          done();
        }, error => {
          window.console.log(error);
          loading();
        });
    },
    rowUpdate(row, index, done, loading) {
      row.deptId = row.deptId.join(",");
      row.roleId = row.roleId.join(",");
      row.postId = row.postId.join(",");
      update(row).then(() => {
        this.initFlag = false;
        this.onLoad(this.page);
        this.$message({
          type: "success",
          message: "操作成功!"
        });
        done();
      }, error => {
        window.console.log(error);
        loading();
      });
    },
    rowDel(row) {
      this.$confirm("确定将选择数据删除?", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return remove(row.id);
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
        });
    },
    searchReset() {
      this.query = {};
      this.treeDeptId = '';
      this.onLoad(this.page);
    },
    searchChange(params, done) {
      this.query = params;
      this.page.currentPage = 1;
      this.onLoad(this.page, params);
      done();
    },
    clickRowChange(row){
      this.$refs.crud.toggleSelection();
      this.selectionList = row;
      this.$refs.crud.setCurrentRow(row);
      this.$refs.crud.toggleRowSelection(row); //选中当前行
    },
    selectionChange(list) {
      this.selectionList = list;
      this.$refs.crud.setCurrentRow(this.selectionList[list.length-1]);
    },
    selectionClear() {
      this.selectionList = [];
      this.$refs.crud.toggleSelection();
    },
    handleDelete() {
      if (this.selectionList.length === 0) {
        this.$message.warning("请选择至少一条数据");
        return;
      }
      this.$confirm("确定将选择数据删除?", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return remove(this.ids);
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
          this.$refs.crud.toggleSelection();
        });
    },
    handleReset() {
      if (this.selectionList.length === 0) {
        this.$message.warning("请选择至少一条数据");
        return;
      }
      this.$confirm("确定将选择账号密码重置为123456?", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return resetPassword(this.ids);
        })
        .then(() => {
          this.$message({
            type: "success",
            message: "操作成功!"
          });
          this.$refs.crud.toggleSelection();
        });
    },
    handleGrant() {
      if (this.selectionList.length === 0) {
        this.$message.warning("请选择至少一条数据");
        return;
      }
      this.roleTreeObj = [];
      if (this.selectionList.length === 1) {
        this.roleTreeObj = this.selectionList[0].roleId.split(",");
      }
      getRoleTree(this.selectionList[0].tenantId).then(res => {
        this.roleGrantList = res.data.data;
        this.roleBox = true;

      });
    },
    handlePlatform() {
      this.platformBox = true;
    },
    handleLock() {
      if (this.selectionList.length === 0) {
        this.$message.warning("请选择至少一条数据");
        return;
      }
      this.$confirm("确定将选择账号解封？", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return unlock(this.ids);
        })
        .then(() => {
          this.$message({
            type: "success",
            message: "操作成功!"
          });
        });
    },
    handleImport() {
      this.excelBox = true;
    },
    uploadAfter(res, done, loading, column) {
      window.console.log(column);
      this.excelBox = false;
      this.refreshChange();
      done();
    },
    handleExport() {
      const account = func.toStr(this.search.account);
      const realName = func.toStr(this.search.realName);
      this.$confirm("是否导出用户数据?", "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      }).then(() => {
        NProgress.start();
        exportBlob(`/api/ubcs-user/export-user?${this.website.tokenHeader}=${getToken()}&account=${account}&realName=${realName}`).then(res => {
          downloadXls(res.data, `用户数据表${dateNow()}.xlsx`);
          NProgress.done();
        })
      });
    },
    handleTemplate() {
      exportBlob(`/api/ubcs-user/export-template?${this.website.tokenHeader}=${getToken()}`).then(res => {
        downloadXls(res.data, "用户数据模板.xlsx");
      })
    },
    beforeOpen(done, type) {
      // console.log(type)
      if(type === "edit"){
        this.isUpdateShowInput = true;
      }else {
        this.isUpdateShowInput = false;
      }
      //console.log(type)
      // console.log('this.tenantId',this.tenantId)
      // const column = this.findObject(this.option.group,'tenantId');
      // column.value=this.tenantId;
      // console.log('column',column)
      // if(this.treeDeptId){
      if (["edit", "view"].includes(type)) {
        getUser(this.form.id).then(res => {
          this.form = res.data.data;
          if (this.form.hasOwnProperty("deptId")) {
            this.form.deptId = this.form.deptId.split(",");
          }
          if (this.form.hasOwnProperty("roleId")) {
            this.form.roleId = this.form.roleId.split(",");
          }
          if (this.form.hasOwnProperty("postId")) {
            this.form.postId = this.form.postId.split(",");
          }
        });
      }
      const prop = this.findObject(this.option.group, 'tenantId');
      //console.log('1',prop)
      this.initFlag = true;
      done();
      // }else {
      //   this.$message.warning('请选择一条所属租户')
      // }
    },
    currentChange(currentPage) {
      this.page.currentPage = currentPage;
    },
    sizeChange(pageSize) {
      this.page.pageSize = pageSize;
    },
    refreshChange() {
      this.onLoad(this.page, this.query);
    },
    onLoad(page, params = {}) {
      this.loading = true;
      getList(page.currentPage, page.pageSize, Object.assign(params, this.query), this.treeDeptId).then(res => {
        const data = res.data.data;
        this.page.total = data.total;
        this.data = data.records;
        this.loading = false;
        this.tenantId=data.records[0].tenantId
        this.selectionClear();
      });
    },
    platformRowUpdate(row, index, done, loading) {
      updatePlatform(row.id, row.userType, row.userExt).then(() => {
        this.platformOnLoad(this.platformPage);
        this.$message({
          type: "success",
          message: "操作成功!"
        });
        done();
      }, error => {
        window.console.log(error);
        loading();
      });
    },
    platformBeforeOpen(done, type) {
      if (["edit", "view"].includes(type)) {
        getUserPlatform(this.platformForm.id).then(res => {
          this.platformForm = res.data.data;
        });
      }
      done();
    },
    platformSearchReset() {
      this.platformQuery = {};
      this.platformOnLoad(this.platformPage);
    },
    platformSearchChange(params, done) {
      this.platformQuery = params;
      this.platformPage.currentPage = 1;
      this.platformOnLoad(this.platformPage, params);
      done();
    },
    platformSelectionChange(list) {
      this.platformSelectionList = list;
    },
    platformSelectionClear() {
      this.platformSelectionList = [];
      this.$refs.platformCrud.toggleSelection();
    },
    platformCurrentChange(currentPage) {
      this.platformPage.currentPage = currentPage;
    },
    platformSizeChange(pageSize) {
      this.platformPage.pageSize = pageSize;
    },
    platformRefreshChange() {
      this.platformOnLoad(this.platformPage, this.platformQuery);
    },
    platformOnLoad(page, params = {}) {
      this.platformLoading = true;
      getList(page.currentPage, page.pageSize, Object.assign(params, this.query), this.treeDeptId).then(res => {
        const data = res.data.data;
        this.platformPage.total = data.total;
        this.platformData = data.records;
        this.platformLoading = false;
        this.selectionClear();
      });
    }
  }
};
</script>

<style lang="scss">
.box {
  height: 800px;
}

.el-scrollbar {
  height: 100%;
}

.box .el-scrollbar__wrap {
  overflow: scroll;
}
.selects{
  width: 100%;
}
.seloption{
  margin-left: 10px;
}
.abox{
  height: 771px;
}

</style>
